"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const plugin_tools_1 = require("@builder.io/plugin-tools");
const shopify_buy_1 = require("shopify-buy");
const package_json_1 = require("../package.json");
const app_context_1 = require("@builder.io/app-context");
const data_plugin_1 = require("./data-plugin");
plugin_tools_1.registerCommercePlugin({
    name: 'Shopify',
    // should always match package.json package name
    id: package_json_1.default.name,
    settings: [
        {
            name: 'storefrontAccessToken',
            type: 'string',
            helperText: 'Required to fetch storefront product data',
            required: true,
        },
        {
            name: 'storeDomain',
            type: 'text',
            helperText: 'Your entire store domain, such as "your-store.myshopify.com"',
            required: true,
        },
        {
            name: 'apiVersion',
            type: 'text',
            helperText: 'Your Shopify API version, such as "2020-04"',
        },
    ],
    ctaText: `Connect your shopify custom app`,
}, async (settings) => {
    const client = shopify_buy_1.default.buildClient({
        storefrontAccessToken: settings.get('storefrontAccessToken'),
        domain: settings.get('storeDomain'),
        apiVersion: settings.get('apiVersion') || '2020-07',
    });
    const service = {
        product: {
            async findById(id) {
                return client.product.fetch(id);
            },
            async findByHandle(handle) {
                return client.product.fetchByHandle(handle);
            },
            async search(search) {
                const sources = (await client.product.fetchQuery({
                    query: search ? `title:*${search}*` : '',
                    sortKey: 'TITLE',
                    first: 250
                })) || [];
                return sources.map((src) => {
                    return {
                        ...src,
                        image: src.image || src.images?.[0],
                    };
                });
            },
            getRequestObject(id) {
                return {
                    '@type': '@builder.io/core:Request',
                    request: {
                        url: `${app_context_1.default.config.apiRoot()}/api/v1/shopify/storefront/product/${id}?apiKey=${app_context_1.default.user.apiKey}&pluginId=${package_json_1.default.name}`,
                    },
                    options: {
                        product: id,
                    },
                };
            },
        },
        collection: {
            async findById(id) {
                return client.collection.fetch(id);
            },
            async findByHandle(handle) {
                return client.collection.fetchByHandle(handle);
            },
            async search(search) {
                return client.collection.fetchQuery({
                    query: search ? `title:*${search}*` : '',
                    sortKey: 'TITLE',
                    first: 250
                });
            },
            getRequestObject(id) {
                return {
                    '@type': '@builder.io/core:Request',
                    request: {
                        url: `${app_context_1.default.config.apiRoot()}/api/v1/shopify/storefront/collection/${id}?apiKey=${app_context_1.default.user.apiKey}&pluginId=${package_json_1.default.name}`,
                    },
                    options: {
                        collection: id,
                    },
                };
            },
        },
    };
    app_context_1.default.registerDataPlugin(data_plugin_1.getDataConfig(service));
    return service;
});
//# sourceMappingURL=plugin.js.map